=== modified file 'lib/Controller/Task.php'
--- lib/Controller/Task.php	2016-10-05 10:34:48 +0000
+++ lib/Controller/Task.php	2016-10-06 11:46:53 +0000
@@ -154,7 +154,10 @@
 
             // Add to the list of available tasks
             foreach ($files as $file) {
-                $data['tasksAvailable'][] = json_decode(file_get_contents($file));
+                $config = json_decode(file_get_contents($file));
+                $config->file = str_replace_first(PROJECT_ROOT, '', $file);
+
+                $data['tasksAvailable'][] = $config;
             }
         }
 
@@ -169,12 +172,13 @@
     {
         $task = $this->taskFactory->create();
         $task->name = $this->getSanitizer()->getString('name');
-        $task->class = $this->getSanitizer()->getString('class');
+        $task->configFile = $this->getSanitizer()->getString('file');
         $task->schedule = $this->getSanitizer()->getString('schedule');
         $task->status = \Xibo\Entity\Task::$STATUS_IDLE;
         $task->lastRunStatus = 0;
         $task->isActive = 0;
         $task->runNow = 0;
+        $task->setClassAndOptions();
         $task->save();
 
         // Return
@@ -193,6 +197,7 @@
     public function editForm($taskId)
     {
         $task = $this->taskFactory->getById($taskId);
+        $task->setClassAndOptions();
 
         $this->getState()->template = 'task-form-edit';
         $this->getState()->setData([
@@ -206,8 +211,22 @@
     public function edit($taskId)
     {
         $task = $this->taskFactory->getById($taskId);
+        $task->setClassAndOptions();
         $task->name = $this->getSanitizer()->getString('name');
         $task->schedule = $this->getSanitizer()->getString('schedule');
+
+        // Loop through each option and see if a new value is provided
+        foreach ($task->options as $option => $value) {
+            $provided = $this->getSanitizer()->getString($option);
+
+            if ($provided !== null) {
+                $this->getLog()->debug('Setting ' . $option . ' to ' . $provided);
+                $task->options[$option] = $provided;
+            }
+        }
+
+        $this->getLog()->debug('New options = ' . var_export($task->options, true));
+
         $task->save();
 
         // Return

=== modified file 'lib/Entity/Task.php'
--- lib/Entity/Task.php	2016-10-05 10:34:48 +0000
+++ lib/Entity/Task.php	2016-10-06 11:46:53 +0000
@@ -8,6 +8,7 @@
 
 namespace Xibo\Entity;
 use Cron\CronExpression;
+use Xibo\Exception\NotFoundException;
 use Xibo\Service\LogServiceInterface;
 use Xibo\Storage\StorageServiceInterface;
 
@@ -26,6 +27,7 @@
 
     public $taskId;
     public $name;
+    public $configFile;
     public $class;
     public $status;
     public $pid;
@@ -59,6 +61,24 @@
         return $cron->getNextRunDate()->format('U');
     }
 
+    /**
+     * Set class and options
+     * @throws NotFoundException
+     */
+    public function setClassAndOptions()
+    {
+        // Get the class and default set of options from the config file.
+        if (!file_exists(PROJECT_ROOT . $this->configFile))
+            throw new NotFoundException(__('Config file not found for Task'));
+
+        $config = json_decode(file_get_contents(PROJECT_ROOT . $this->configFile), true);
+        $this->class = $config['class'];
+        $this->options = array_merge($config['options'], $this->options);
+    }
+
+    /**
+     * Save
+     */
     public function save()
     {
         if ($this->taskId == null)
@@ -67,6 +87,9 @@
             $this->edit();
     }
 
+    /**
+     * Delete
+     */
     public function delete()
     {
         $this->getStore()->update('DELETE FROM `task` WHERE `taskId` = :taskId', ['taskId' => $this->taskId]);
@@ -75,16 +98,17 @@
     private function add()
     {
         $this->taskId = $this->getStore()->insert('
-            INSERT INTO `task` (`name`, `status`, `class`, `pid`, `options`, `schedule`, 
+            INSERT INTO `task` (`name`, `status`, `configFile`, `class`, `pid`, `options`, `schedule`, 
               `lastRunDt`, `lastRunMessage`, `lastRunStatus`, `lastRunDuration`, `lastRunExitCode`,
               `isActive`, `runNow`) VALUES
-             (:name, :status, :class, :pid, :options, :schedule, 
+             (:name, :status, :configFile, :class, :pid, :options, :schedule, 
               :lastRunDt, :lastRunMessage, :lastRunStatus, :lastRunDuration, :lastRunExitCode,
               :isActive, :runNow)
         ', [
             'name' => $this->name,
             'status' => $this->status,
             'pid' => $this->pid,
+            'configFile' => $this->configFile,
             'class' => $this->class,
             'options' => json_encode($this->options),
             'schedule' => $this->schedule,
@@ -105,6 +129,7 @@
               `name` = :name, 
               `status` = :status, 
               `pid` = :pid,
+              `configFile` = :configFile,
               `class` = :class,
               `options` = :options, 
               `schedule` = :schedule, 
@@ -121,6 +146,7 @@
             'name' => $this->name,
             'status' => $this->status,
             'pid' => $this->pid,
+            'configFile' => $this->configFile,
             'class' => $this->class,
             'options' => json_encode($this->options),
             'schedule' => $this->schedule,

=== modified file 'lib/Factory/TaskFactory.php'
--- lib/Factory/TaskFactory.php	2016-10-05 10:34:48 +0000
+++ lib/Factory/TaskFactory.php	2016-10-06 11:46:53 +0000
@@ -100,7 +100,7 @@
         $entries = array();
         $params = array();
         $sql = '
-          SELECT `taskId`, `name`, `status`, `pid`, `class`, `options`, `schedule`, 
+          SELECT `taskId`, `name`, `status`, `pid`, `configFile`, `class`, `options`, `schedule`, 
               `lastRunDt`, `lastRunMessage`, `lastRunStatus`, `lastRunDuration`, `lastRunExitCode`,
               `isActive`, `runNow`
             FROM `task` 

=== modified file 'views/task-form-add.twig'
--- views/task-form-add.twig	2016-10-04 16:37:08 +0000
+++ views/task-form-add.twig	2016-10-06 11:46:53 +0000
@@ -27,7 +27,7 @@
 
                 {% set title %}{% trans "Task" %}{% endset %}
                 {% set helpText %}{% trans "Select the task you would like to run" %}{% endset %}
-                {{ forms.dropdown("class", "single", title, "", tasksAvailable, "class", "name", helpText) }}
+                {{ forms.dropdown("file", "single", title, "", tasksAvailable, "file", "name", helpText) }}
 
                 {% set title %}{% trans "Name" %}{% endset %}
                 {% set helpText %}{% trans "The Name for this Task" %}{% endset %}

=== modified file 'views/task-form-edit.twig'
--- views/task-form-edit.twig	2016-10-04 16:37:08 +0000
+++ views/task-form-edit.twig	2016-10-06 11:46:53 +0000
@@ -32,6 +32,9 @@
                 {% set helpText %}{% trans "The schedule for this task in CRON syntax" %}{% endset %}
                 {{ forms.input("schedule", title, task.schedule, helpText, "", "required") }}
 
+                {% for option,value in task.options %}
+                    {{ forms.input(option, option, value) }}
+                {% endfor %}
             </form>
         </div>
     </div>

